
#include "spi.h"
#include "ssi.h"

extern uint8_t rdynFlag;

// This function configures the low level SPI interface
// to the nRF8001, both pins and module itself.
// SCLK, MOSI and MISO pin are standard SPI pins.
// REQN is an output to tell the nRF8001 we want to
// transmit data. RDYN is an input and informs us
// that the nRF8001 slave is ready to receive
// data
void configureNRF8001Interface()
{
	//
	// Enable the GPIO ports
	//
	ROM_SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOB);
	ROM_SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOE);

	// Initialize GPIO

	// PB.0 RESET signal as GPIO Output
	GPIODirModeSet(GPIO_PORTB_BASE, GPIO_PIN_0,GPIO_DIR_MODE_OUT);
	 GPIOPadConfigSet(GPIO_PORTB_BASE, GPIO_PIN_0, GPIO_STRENGTH_2MA, GPIO_PIN_TYPE_STD);

	// PE.4 REQN signal as GPIO Output
	GPIODirModeSet(GPIO_PORTE_BASE, GPIO_PIN_4,GPIO_DIR_MODE_OUT);
	 GPIOPadConfigSet(GPIO_PORTE_BASE, GPIO_PIN_4, GPIO_STRENGTH_2MA, GPIO_PIN_TYPE_STD);


	// PB.1 RDYN signal as GPIO Input
	GPIOIntRegister(GPIO_PORTB_BASE,rdynHandler);
	GPIODirModeSet(GPIO_PORTB_BASE,GPIO_PIN_1,GPIO_DIR_MODE_IN);
    GPIOPadConfigSet(GPIO_PORTB_BASE, GPIO_PIN_1, GPIO_STRENGTH_2MA, GPIO_PIN_TYPE_STD);

	GPIOIntClear(GPIO_PORTB_BASE,GPIO_INT_PIN_1);
	GPIOIntTypeSet(GPIO_PORTB_BASE,GPIO_INT_PIN_1,GPIO_FALLING_EDGE);
	GPIOIntEnable(GPIO_PORTB_BASE, GPIO_INT_PIN_1);

	IntEnable(INT_GPIOB);

	// Enable clock for SSI Module
	ROM_SysCtlPeripheralEnable(SYSCTL_PERIPH_SSI2);

	// Enable SSI/SPI Pins, SCLK, TX, RX
	GPIOPinConfigure(GPIO_PB4_SSI2CLK);
	GPIOPinConfigure(GPIO_PB7_SSI2TX);
	GPIOPinConfigure(GPIO_PB6_SSI2RX);
	GPIOPinTypeSSI(GPIO_PORTB_BASE,GPIO_PIN_4 | GPIO_PIN_6 | GPIO_PIN_7);

	// Configure SSI Module for Master 2MHz Clock Phase 0 Polarity 0 and 8 bits
	SSIConfigSetExpClk(SSI2_BASE,SysCtlClockGet(),SSI_FRF_MOTO_MODE_0,SSI_MODE_MASTER,2000000,8);

	// Enable SSI Module
	SSIEnable(SSI2_BASE);
}

// Resets the nRF8001 device, generating a Device Started event
void reset_nrf8001()
{
	// Release reset

	// Set HIGH
	GPIOPinWrite(GPIO_PORTB_BASE,GPIO_PIN_0,GPIO_PIN_0);
	SysCtlDelay(10);

	// Set LOW
	GPIOPinWrite(GPIO_PORTB_BASE,GPIO_PIN_0,0);
	SysCtlDelay(100);

	// Set HIGH
	GPIOPinWrite(GPIO_PORTB_BASE,GPIO_PIN_0,GPIO_PIN_0);
	SysCtlDelay(10);
}

void rdynHandler(void)
{
	GPIOIntClear(GPIO_PORTB_BASE,GPIO_INT_PIN_1);
	SysCtlDelay(10);

	// Check if RDYN was triggered
	if((GPIOPinRead(GPIO_PORTB_BASE, GPIO_PIN_1) & GPIO_PIN_1) == 0)
	{
		// Set flag so it can be processed in the main loop
		rdynFlag = 1;
		m_rdy_line_handle();

	}
}
